package gpsys.cos;

import java.awt.*;
import java.io.*;

/**
 * Provides a view of the terrain and terrain robot on the terrain.
 *
 * @see			gpsys.cos.Cos
 * @see			gpsys.cos.TerrainObserver
 *
 * @version             1.1, 24 Mars 1999
 * @author      <a href="mailto:epierre@e-nef.com">Emmanuel PIERRE</a>
 *                      <address>DEA IARFA,</address>
 */
public class TerrainViewer extends Canvas implements TerrainObserver {
	/**
	 * The terrain being monitored.
	 */
	Terrain	terrain;
	/**
	 * The current X-coordinate of the terrainrobot.
	 */
	int robot1X;
	/**
	 * The current Y-coordinate of the terrainrobot.
	 */
	int robot1Y;

	TextField txt;
	TextArea  txtA;

	/**
	 * Create a new TerrainViewer Object which provides a view of the specified
	 * Terrain.
	 *
	 * @param terrain	The Terrain being viewed.
	 */
	public TerrainViewer(Terrain terrain) {
		this.terrain = terrain;
                txt = new TextField("",50);
                txtA = new TextArea("",6,50);
	}

        public void printTxt(String str) {
		//txtA.replace("");
		if (terrain.observed==true)
			txtA.append(str);
	}

        public void printInfo(String str) {
		if (terrain.observed==true)
			txt.setText(str);
	}

	/**
	 * Initialise the position of the robot on the terrain.
	 */
	public void init() {
                terrain.terrain[1][6]=Terrain.L0;
                terrain.terrain[5][2]=Terrain.L1;
                terrain.terrain[3][8]=Terrain.L2;
                terrain.terrain[5][7]=Terrain.CS;

	}

	/**
	 * Override the Canvas update() method so that the Canvas is not cleared
	 * before it is redrawn.
	 *
	 * @param g	The graphics Object associated with the Canvas.
	 */
	public void update(Graphics g) {
		paint(g);
	}

	/**
	 * Override the Canvas paint() method so that the terrain and terrain robot
	 * is drawn on the Canvas.
	 *
	 * @param g	The graphics Object associated with the Canvas.
	 */
	public void paint(Graphics g) {
		for (int i = 0; i < terrain.terrain.length; i++)
			for (int j = 0; j < terrain.terrain.length; j++) {
				if (terrain.terrain[i][j] == Terrain.CS)
					g.setColor(Color.blue);
				else if (terrain.terrain[i][j] == Terrain.R1)
                                        g.setColor(Color.green);
				else if (terrain.terrain[i][j] == Terrain.R2)
                                        g.setColor(Color.green);
				else if (terrain.terrain[i][j] == Terrain.L0)
                                        g.setColor(Color.yellow);
				else if (terrain.terrain[i][j] == Terrain.L1)
                                        g.setColor(Color.yellow);
				else if (terrain.terrain[i][j] == Terrain.L2)
                                        g.setColor(Color.yellow);
				else
					g.setColor(Color.white);
				g.fillRect(i * 50, j * 50, 50, 50);
			}
		g.setColor(Color.black);
		g.fillRect(robot1X * 50, robot1Y * 50, 50, 50);
	}

	/**
	 * Update the terrain view when the terrain regrows.
	 */
	public void terrainInit() {
                terrain.terrain[1][6]=Terrain.L0;
                terrain.terrain[5][2]=Terrain.L1;
                terrain.terrain[3][8]=Terrain.L2;
                terrain.terrain[5][7]=Terrain.CS;
		repaint();
		try {
			Thread.sleep(400);
		}
		catch (InterruptedException e) {}
	}

	/**
	 * Update the terrain view when a square on the terrain is being cut.
	 *
	 * @param x	The X-coordinate of the square being cut.
	 * @param y	The Y-coordinate of the square being cut.
	 */
	public void robotMoved(int x, int y) {
		robot1X = x;
		robot1Y = y;
		repaint();
		try {
			Thread.sleep(400);
		}
		catch (InterruptedException e) {}
	}
}
